@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.7.1-0
-#Date 17 February 2010
+# Application Name - Health Check V0.7.2-0
+# Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
 #
@@ -10,18 +10,10 @@
 #
 # This is my first ever N900 application, so please excuse the poor coding!
 #
-# If you are running this in python directly you will need the following packages.
-# In terminal run these commands:
-# sudo gainroot
-# apt-get install python2.5-qt4-gui
-# apt-get install python-location
-#
-# files: Ensure that gn_cellinfo is in the same folder as the healthcheck.py file.
 #
 # Talk/Bugs : http://talk.maemo.org/showthread.php?t=45453
 #
 # Import the libraries needed in this program
-# Basic ones
 # import PyQt4 & sys
 print "** Start Imports **"
 print "** Importing qtcore & gui **"
@@ -607,7 +599,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_5)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V0.7.1-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
+		self.textBrowser.setText (" Health Check V0.7.2-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec(Accuracy test), Rob1n(App window) & Lcuk(Everything!)\n And to all the testers.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -871,10 +863,7 @@ class Ui_MainWindow(object):
 		#self.lbl_Alt_Info.setText(var_g_ALT)
 		self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
 		al = '/sbin/ifconfig | grep inet | grep -v 127.0.0.1 | awk \'{split($2,a,":");print a[2]}\''
-		l = None
-		l = os.popen(al).read()
-		self.listWidget2.addItem("Internal IP \t\t" + l.strip())
-		print "** Updated GPS Info**"
+
 
 
 	def reboot_sys(self):
@@ -979,7 +968,7 @@ class Ui_MainWindow(object):
 		gb = gb.strip()[11:]
 		
 		self.listWidget.addItem("N900 Board \t\t\t" + gb.strip())
-		print " ** Getting board info revision**"
+		print " ** Getting board info revision **"
 		gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
 		gj = gj.strip()[11:]
 		
@@ -996,31 +985,46 @@ class Ui_MainWindow(object):
 		gd = gd.strip()
 		self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
 
+                print " ** Getting FM Transmitter power level **"
 		ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
 		ge = ge.strip()
-	
 		self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
 
+                print " ** Getting Boot Reason**"
 		gl = os.popen('cat /proc/bootreason').read()
 		gl = gl.strip()	
 		self.listWidget.addItem("Boot Reason (last) \t\t" + gl.strip())
 
+                print " ** Getting Cam Shutter State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Camera Shutter State \t" + gl.strip())
 
+                print " ** Getting Keyboard Slider State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Keyboard Slider State \t" + gl.strip())
 
+                print " ** Getting proximity sensor state**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Proximity Sensor State \t" + gl.strip())
 
-		gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state ').read()
+                print " ** Getting headphone state**"
+		gl = os.popen('cat /sys/devices/platform/gpio-switch/headphone/state').read()
 		gl = gl.strip()
 		self.listWidget.addItem("Headphone State \t\t" + gl.strip())
 
+		print " ** Getting battery mAh info**"
+		gl = os.popen('hal-device bme | awk \'/g.c/ {print $3" mAh"}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Battery current mAh \t\t" + gl.strip())
+		
+                print " ** Getting battery mAh info2**"
+		gl = os.popen('hal-device bme | awk \'/g.la/ {print $3" mAh"}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Battery last charge mAh \t" + gl.strip())
+
  
 		
 	def updatenetname(self):
@@ -1046,7 +1050,28 @@ class Ui_MainWindow(object):
 		#b = os.popen('run-standalone.sh dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_registration_status').read()
 		#b=str(b)
 		#self.listWidget.addItem("Phone Registration \t" + b.strip())
+
+		print " ** Getting IP INFO*"
+                ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
+		ga = ga.strip()
+		self.listWidget2.addItem("IP Internal \t\t" + ga.strip())
+
+		print " ** Getting Wireless Info*"
+                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $3}\' | awk -F. \'/./ {print $1" %"}\'').read()
+		ga = ga.strip()
+		self.listWidget2.addItem("WIFI Link Quality \t" + ga.strip())
+
+		print " ** Getting Wireless Info RSSI*"
+                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $4" dBm"}\'').read()
+		ga = ga.strip()
+		self.listWidget2.addItem("WIFI RSSI \t\t" + ga.strip())
 		
+		print " ** Getting Wireless Info Noise*"
+                ga = os.popen('cat /proc/net/wireless | awk \'/0/ {print $5}\' | awk -F. \'/./ {print $1" dBm"}\'').read()
+		ga = ga.strip()
+		self.listWidget2.addItem("WIFI Noise \t\t" + ga.strip())
+
+
 		
 	def updateUptime(self):
 		print " ** Getting system uptime**"
@@ -1059,19 +1084,11 @@ class Ui_MainWindow(object):
 
 # Funtion - update battery information
 	def updateBatt(self):
-		print " ** Getting battery percentage**"
-		# This one pulls out the battery percentage
-		bg = os.popen('lshal|grep percen').read()
-		# This one reads the applications list from dpkg
-		# Do some string functions to find/remove messy parts of the battery pulled text.
-		# Please excuse the poorly labeled variables here!
-		C_a = str(bg)[:-15]
-		C_b = str(C_a)[-4:]
-		barxval = str.strip(C_b)
-		
-		#self.lbl_Battery_Bar.setRange(0,100)
-		#self.lbl_Battery_Bar.setProperty("value", barxval)
-		self.listWidget.addItem("Battery  \t\t\t" + barxval + "%")
+
+		print " ** Getting battery charge**"
+		gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Battery charge \t\t" + gl.strip())
 
 # Funtion - update Accelerator information
 	def updateAccel(self):
@@ -1160,14 +1177,67 @@ class Ui_MainWindow(object):
 
 # Funtion - update rootfs, currently shows free MB and used %.
 	def updaterootfs(self):
-		print " ** Getting rootfs space**"
+		print " ** Getting rootfs space commands**"
 		# Call the x-terminal command to read the rootfs free space
-		gr = os.popen('df -h /').read()
-		# Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
-		gx = str(gr)[-14:]
-		gx = gx[:-7]
+
+		print " ** Getting rootfs % used **"
+		gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Rootfs % Used \t\t" + gl.strip())
+
+		print " ** Getting rootfs free MB **"
+		gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Rootfs MB Free \t\t" + gl.strip())
+
+		print " ** Getting myDocs % Used **"
+		gl = os.popen('df /home/user/MyDocs | awk \'/My/ {print $5}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("MyDocs % Used \t\t" + gl.strip())
+
+		print " ** Getting myDocs MB Free **"
+		gl = os.popen('df -h /home/user/MyDocs | awk \'/My/ {print $4}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("MyDocs MB Free \t\t" + gl.strip())
+
+                print " ** Getting App Space **"
+		gl = os.popen('df /home | awk \'/ho/ {print $5}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("App/Home % Used \t\t" + gl.strip())
+
+		print " ** Getting App MB Free **"
+		gl = os.popen('df -h /home | awk \'/ho/ {print $4}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("App/Home MB Free \t\t" + gl.strip())
+
+		print " ** Getting MMC Space **"
+		gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Memory Card % Used \t" + gl.strip())
+
+		print " ** Getting MMC MB Free **"
+		gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
+		gl = gl.strip()
+		self.listWidget.addItem("Memory Card Free \t\t" + gl.strip())
+
+		print " ** Getting CPU Frequency **"
+		gl = os.popen('echo $((`cat /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq`/1000)) MHz').read()
+		gl = gl.strip()
+		self.listWidget.addItem("CPU Frequency \t\t" + gl.strip())
+
+		#print " ** Getting RAM Used **"
+		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$3/1024)}\'').read()
+		#gl = gl.strip()
+		#self.listWidget.addItem("Memory - RAM Used \t" + gl.strip())
+		
+		#print " ** Getting RAM Free **"
+		#gl = os.popen('free | awk \'/M/ {printf ("%.1f MB\n",$4/1024)}\'').read()
+		#gl = gl.strip()
+		#self.listWidget.addItem("Memory - RAM Free \t" + gl.strip())
+		
+		
+
 		
-		self.listWidget.addItem("Rootfs \t\t\t" + gx.strip() + " free")
 
 	def updatemydocs(self):
 		print " ** Getting MyDocs space**"
@@ -1227,7 +1297,7 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.1-0", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V0.7.2-0", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
@@ -1330,11 +1400,12 @@ def on_changed(device, data):
 		for i in range(1, 5):
 			if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
 				print " ** Looping GPS Fix **"
+				print "lat = %f, long = %f" % device.fix[4:6]
 				print device.fix
 				var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
 				#print "horizontal accuracy: %f meters" % (device.fix[6] / 100)
-			if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
-				var_g_ALT = "altitude = %f" % device.fix[7]
+			#if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
+				#var_g_ALT = "altitude = %f" % device.fix[7]
 				#print "altitude = %f" % device.fix[7]
 
 			data.stop()
